<?php

namespace Payment\Payment\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Payment\Payment\Http\Requests\PaymentsUserRequest;
use Payment\Payment\Interfaces\PaymentsRepositoryInterface;
use Response;
use User;

class PaymentsUserController extends UserController
{
    /**
     * Initialize payments controller.
     *
     * @param type PaymentsRepositoryInterface $payments
     *
     * @return type
     */
    public function __construct(PaymentsRepositoryInterface $payments)
    {
        $this->model = $payments;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PaymentsUserRequest $request)
    {
        $payments = $this->model->all();

        $this->theme->prependTitle(trans('payment::payments.names').' :: ');

        return $this->theme->of('payment::user.payments.index', compact('payments'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(PaymentsUserRequest $request, $role, $id)
    {
        $payments = $this->model->find($id);

        return $this->theme->of('payment::user.payments.show', compact('payments'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PaymentsUserRequest $request)
    {
        $payments = $this->model->findOrNew(0);

        Former::populate($payments);

        return $this->theme->of('payment::user.payments.create', compact('payments'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PaymentsUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $payments = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('payment::payments.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(PaymentsUserRequest $request, $role, $id)
    {
        $payments = $this->model->find($id);

        Former::populate($payments);

        return $this->theme->of('payment::user.payments.edit', compact('payments'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(PaymentsUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $payments = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('payment::payments.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PaymentsUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('payment::payments.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
